@@ -29,8 +29,10 @@ module="all"
 tier="web"
 djrestart=yes
 rolling=yes
+stop_djs_at_start=no
+common_stuff_run=no
 
-while getopts "he:v:m:s:dr" opt; do
+while getopts "he:v:m:s:drtc" opt; do
     case $opt in
         h) usage 0
             ;;
@@ -40,8 +42,12 @@ while getopts "he:v:m:s:dr" opt; do
             ;;
         s) out_path=$OPTARG
             ;;
+        c) common_stuff_run=yes
+            ;;
         r) rolling=no
             ;;
+        t) stop_djs_at_start=yes
+            ;;
         d) djrestart=no
             ;;
         \?)
@@ -63,7 +69,6 @@ if [ "x${out_path}" == "x" ];then
   exit 1
 fi
 
-
 EXIT_STATUS=1
 function clean_up {
   release_lock
@@ -97,6 +102,14 @@ trap "clean_up" EXIT
 # How will we get the pemfile for nokia
 echo "Deploying module: $module  to tier: $tier on environment: ${env_str}" >& 2
 
+#Running common stuff before running main deploy helps in transferring some config files to all nodes
+if [ "$common_stuff_run" == "yes" ]; then
+  runlist='{"run_list":["recipe[webslave::common_stuff]"]}'
+  chef_command="echo '${runlist}' > /tmp/runlist12; sudo chef-client -j /tmp/runlist12"
+  knife ssh "$selector" "$chef_command" -x ec2-user -i $pemfile -a ec2.public_hostname --no-host-key-verify
+fi
+  
+
 if [ "$module" == "all" ]; then
     chef_command="sudo chef-client -j /etc/chef/first-boot.json -E ${env_str}"
 else
@@ -104,9 +117,6 @@ else
     chef_command="echo '${runlist}' > /tmp/runlist; sudo chef-client -j /tmp/runlist"
 fi
 
-# clean up dead nodes
-cd ${out_path}/chef-repo
-yes y | rake reap_instances
 cd ${d}
 
 # set the target install version on all nodes in this environment
@@ -143,7 +153,7 @@ if [ "x$djrestart" == "xno" ]; then
   fi
 elif [ \( "$module" == "all" -o "$module" == "tapp2" -o "$module" == "hive" \) -a "x$rolling" == "xyes" ]; then
   #do rolling upgrade if possible
-  /usr/bin/env ruby ${d}/rolling_deploy.rb ${env_str} $host $password $username $database $lb_name ${pemfile}
+  /usr/bin/env ruby ${d}/rolling_deploy.rb ${env_str} $host $password $username $database $lb_name ${pemfile} ${stop_djs_at_start}
 else
   selectorfinal="${selector} AND NOT shutdown_gracefully:yes"
   knife ssh "$selectorfinal" "$chef_command" -x ec2-user -i $pemfile -a ec2.public_hostname --no-host-key-verify
@@ -152,3 +162,4 @@ trap - INT HUP TERM QUIT
 
 EXIT_STATUS=0
 
+
